<?php

namespace Drupal\simple_datatables_integration\Plugin\views\style;

use Drupal\views\Plugin\views\style\Table;
use Drupal\Core\Form\FormStateInterface;

/**
 * Style plugin to render a table as a Simple DataTable.
 *
 * @ingroup views_style_plugins
 *
 * @ViewsStyle(
 *   id = "simple_datatables",
 *   title = @Translation("Simple DataTables"),
 *   help = @Translation("Render a table as a Simple DataTable."),
 *   theme = "views_style_simple_data_table",
 *   display_types = { "normal" }
 * )
 */
class SimpleDataTables extends Table {

  /**
   * {@inheritdoc}
   */
  protected $usesFields = TRUE;

  /**
   * {@inheritdoc}
   */
  protected $usesRowPlugin = FALSE;

  /**
   * {@inheritdoc}
   */
  protected $usesRowClass = TRUE;

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['simple_datatables_settings'] = [
      'default' => [
        'labels' => [
          'placeholder' => $this->t('Search...'),
          'perPage' => $this->t('Records per page'),
          'noRows' => $this->t('No results found'),
          'info' => $this->t('Showing {start} to {end} of {rows} records (Page {page} of {pages})'),
        ],
        'custom_options' => '',
      ],
    ];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    foreach ($form['info'] as $key => $value) {
      unset($form['info'][$key]['default_sort_order']);
      unset($form['default'][$key]);
    }

    $form['simple_datatables_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Simple DataTables Settings'),
    ];

    $form['simple_datatables_settings']['labels'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Labels'),
    ];

    $form['simple_datatables_settings']['labels']['placeholder'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Search Placeholder'),
      '#default_value' => $this->options['simple_datatables_settings']['labels']['placeholder'],
    ];

    $form['simple_datatables_settings']['labels']['perPage'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Per Page Label'),
      '#default_value' => $this->options['simple_datatables_settings']['labels']['perPage'],
    ];

    $form['simple_datatables_settings']['labels']['noRows'] = [
      '#type' => 'textfield',
      '#title' => $this->t('No Rows Label'),
      '#default_value' => $this->options['simple_datatables_settings']['labels']['noRows'],
    ];

    $form['simple_datatables_settings']['labels']['info'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Info Label'),
      '#description' => $this->t('Use the following variables in the text: {start}, {end}, {rows}, {page}, {pages}. Example: "Showing {start} to {end} of {rows} rows (Page {page} of {pages} pages)"'),
      '#default_value' => $this->options['simple_datatables_settings']['labels']['info'],
    ];

    $form['simple_datatables_settings']['custom_options'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Custom Options'),
      '#description' => $this->t('Add custom options for Simple DataTables in JSON format. These options will override the default settings.'),
      '#default_value' => $this->options['simple_datatables_settings']['custom_options'],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    $build = parent::render();
    // Add additional render logic here if needed.
    return $build;
  }

}
